@@ -7,7 +7,7 @@ use diagnostics;
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw( auction );
-our $VERSION = '0.86';
+our $VERSION = '0.87';
 
 #Variables global to the package	
 my $maximize_total_benefit;
@@ -434,9 +434,9 @@ sub get_matrix_info {
 sub auctionRound {
 	my ( $matrix_ref, $epsilon, $verbose ) = @_;
 	my @matrix = @$matrix_ref;
-	my ( %info, %choose_object, %count_object );
+	my ( %info, %choose_object, %count_object, %choose_person );
 	my %this_person_can_choose_n_different_objects;
-	my %objects_with_the_same_values;	
+	my %objects_with_the_same_values;
 	
 	my $number_of_assignned_object = scalar keys %assignned_object;	
 
@@ -494,7 +494,7 @@ sub auctionRound {
 				my $matrix_value = $seen_ghost ? 0 : $matrix[$person]->[$object];
 				$current_value{$object} = $matrix_value - $price_object{$object};
 				
-				push @updated_price, $object if ( $objects_desired_by_this{$person}{$object} == $current_value{$object} );				
+				push @updated_price, $object if ( $objects_desired_by_this{$person}{$object} == $current_value{$object} );								
 				
 				if ( $current_value{$object} > $Opt01ValForPersonI ) # search for the best 3 objects
 				{
@@ -610,8 +610,7 @@ sub auctionRound {
 				{
 					$Opt03ValForPersonI = $Opt03ValForPersonI_new_list;
 					$Opt03ObjForPersonI = $Opt03ObjForPersonI_new_list;
-				}				
-
+				}
 			}
 			
 			$bidForPersonI = $Opt01ValForPersonI - $Opt02ValForPersonI + $epsilon;
@@ -666,8 +665,8 @@ sub auctionRound {
 				$objects_desired_by_this{$person}{$Opt02ObjForPersonI} = $current_value{$Opt02ObjForPersonI} if (defined $Opt02ObjForPersonI);
 				$objects_desired_by_this{$person}{$Opt03ObjForPersonI} = $current_value{$Opt03ObjForPersonI} if (defined $Opt03ObjForPersonI);				
 
-				$locked_list{$person} = 1 if ( $epsilon_scaling > (1/5) * $max_epsilon_scaling and ($Opt03ValForPersonI - $Opt01ValForPersonI_new_list) > $min_size * $epsilon );
-				$locked_list{$person} = 1 if ( $epsilon_scaling > (2/5) * $max_epsilon_scaling ); # Lock the old list. Is this the minimum value to find a possible solution?
+				$locked_list{$person} = 1 if ( $epsilon_scaling > (1/10) * $max_epsilon_scaling and ($Opt03ValForPersonI - $Opt01ValForPersonI_new_list) > $min_size * $epsilon );
+				$locked_list{$person} = 1 if ( $epsilon_scaling > (3/10) * $max_epsilon_scaling ); # Lock the old list. Is this the minimum value to find a possible solution?
 				delete $locked_list{$person} if ( $epsilon == 1/(1+$min_size) ); # Otherwise unlock the person's old list in the last $epsilon_scaling round.
 			}
 			
@@ -688,11 +687,9 @@ sub auctionRound {
 			}
 		}
 	}
-	
-	my %choose_person;
-	
+
 	# first, choose objects that appear a few times
-    foreach my $object ( sort { $count_object{$a} <=> $count_object{$b} || $seen_assignned_objects{$a} <=> $seen_assignned_objects{$b} } keys %objects_with_the_same_values ){ # sort { $count_object{$a} <=> $count_object{$b} || $seen_assignned_objects{$a} <=> $seen_assignned_objects{$b} || $price_object{$a} <=> $price_object{$b} }
+	foreach my $object ( sort { $count_object{$a} <=> $count_object{$b} || $seen_assignned_objects{$a} <=> $seen_assignned_objects{$b} } keys %objects_with_the_same_values ){ # sort { $price_object{$b} <=> $price_object{$a} }
 	foreach my $person ( keys %{$objects_with_the_same_values{$object}} ){ # sort { $objects_with_the_same_values{$object}{$a} <=> $objects_with_the_same_values{$object}{$b} }
 		
 		next if ( $choose_object{$object} );
@@ -704,7 +701,7 @@ sub auctionRound {
 		$info{$Opt01ObjForPersonI}{'bid'   } = $epsilon;
 		$info{$Opt01ObjForPersonI}{'person'} = $person;
 			
-		$objects_desired_by_this{$person}{$object} = $CurVal;								
+		$objects_desired_by_this{$person}{$object} = $CurVal;							
 		
 		if ( $verbose >= 8 ){
 		
@@ -804,6 +801,9 @@ __END__
 
 =head1 SYNOPSIS
 
+ ### --- simple and direct application --- ###
+ ### ---            start              --- ###
+
  #!/usr/bin/perl
 
  use strict;
@@ -870,6 +870,9 @@ __END__
 	$value = defined $value ? sprintf( "%6s", $value ) : ' ' x 6 ; # %6s  
 	printf " Auction Algorithm, (row, column) indexes --> \$i = %3d ; \$j = %3d ; \$value = $value ; \$sum = %8s \n", $i, $j, $sum;
  }
+ 
+ ### ---            final              --- ###
+ ### --- simple and direct application --- ###
 
  Example 1: Find the nearest neighbor, Minimize the total benefit.
 
@@ -1069,7 +1072,7 @@ __END__
 =head1 AUTHOR
 
     Claudio Fernandes de Souza Rodrigues
-	May 19, 2018
+	May 21, 2018
 	Sao Paulo, Brasil
 	claudiofsr@yahoo.com
 	
